function PlotResidual(grp,EQ,DATA,xname,yname,fit)
%PlotResidual(grp,DATA,xname,yname) Plots residual data
%   Kevin Mackie, 2001/07/19
%   University of California Berkeley
%   Department of Civil and Environmental Engineering
%   mackie@ce.berkeley.edu
%
%   INPUT: grp (Ax3) matrices of data in linear space
%          A corresponds to total number of input files considered
%          1st column is x (DM), 2nd column y (IM), 3rd column is M,R, etc
%          make sure correction for SI units is appropriate 
%          EQ number of earthquake bins sent in
%          DATA array of information about group and type
%          xname label for x-axis
%          yname label for y-axis
%          fit 1 linear 2 bilinear
%
% Interpolation functions are fitting the DM given the IM (ie, y given x)
% but don't be fooled by the "reversed" axis plotting of these measures
% Output linear fits are of form log(DM)=A+B log(IM)
%
% Plots the residual of the IM DM relationship (DMfit-DM) versus dependent
% quantities such as Magnitude (M) and Distance (R)

[m,n]=size(grp);

[xylog,linexlog,lineylog,Fits,Dispersion]=FitData(grp,fit,EQ);

for k=1:n
   % Calculate residuals (in log space)
   res{k}=log(linexlog{k})-log(xylog{k}.v(:,1));
   logres{k}=exp(res{k});

   % Linear fit to residuals (in linear-log space)
   N=1;
   P{k}.v=polyfit(xylog{k}.v(:,3),res{k},N);
   
   liney{k}=xylog{k}.v(:,3);
   linex{k}=zeros(length(liney{k}),1);

   for i=0:N,
      linex{k}=linex{k}+P{k}.v(i+1)*liney{k}.^(N-i);
   end;

   linexlog{k}.v=exp(linex{k});
   [liney{k},iy{k}]=sortrows(liney{k});
   linexlog{k}.v=linexlog{k}.v(iy{k});
end;

%slopes=[P1(1),P2(1),P3(1),P4(1)]

HH = findobj('Tag','Axes1');     	% axes must be named Axes1 in GUI
axes(HH);						    % make them current

clrs='brmgcykbrmgcy';
lins='ox+^*sdv<>ph.';

logplot='H=semilogy(';
legplot='legend(';
for k=1:n,
   logplot=sprintf('%sxylog{%i}.v(:,3),logres{%i},''%c%c'', ', ...
      		logplot,k,k,clrs(k),lins(k));
end
for k=1:n,
   logplot=sprintf('%sliney{%i},linexlog{%i}.v,''%c--''',logplot,k,k,clrs(k));
   legplot=sprintf('%sstrcat(DATA.name,''='',num2str(DATA.vals(%i)))',legplot,k);
   if k<n,
      logplot=sprintf('%s, ',logplot);
	  legplot=sprintf('%s, ',legplot);
   end;
end

logplot=sprintf('%s);',logplot);
legplot=sprintf('%s,4);',legplot);

eval(logplot);
axis tight;
set(H,'MarkerSize',4);
grid on;
xlabel(xname);
ylabel(strcat(yname,' residual'));
title('Residual Dependence (semilog scale)');
eval(legplot);
set(HH,'Tag','Axes1');

vax=axis;

% add slope info to plot
siginf='c (*E^-^2)=';
for k=1:n,
   siginf=sprintf('%s%1.2f',siginf,P{k}.v(1)*100);
   if k<n,
      siginf=sprintf('%s, ',siginf);
   end;
end;
TT=text( vax(1)+(vax(2)-vax(1))/100, vax(4)-(vax(4)-vax(3))/100 ,siginf);
set(TT,'Tag','sigma');
set(TT,'FontSize',9);
set(TT,'VerticalAlignment','top');
